==> deepin-screenshot_4.1.8.orig.tar.gz: deepin-screenshot-4.1.8/CHANGELOG.md <==
<a name="4.1.8"></a>
### 4.1.8 (2019-02-25)


#### Bug Fixes

*   unable to use the open file under other notifications ([0df34426](https://github.com/linuxdeepin/deepin-screenshot/commit/0df34426563b72aefc7d51c3a858dc3ce4451d84))



<a name="4.1.7"></a>
## 4.1.7 (2019-01-25)


#### Features

*   Hold shift to avoid remember save state ([26a5f60a](https://github.com/linuxdeepin/deepin-screenshot/commit/26a5f60a29f5815cbfde00cf8091979df92b450c))



<a name="4.1.6"></a>
### 4.1.6 (2019-01-14)


#### Bug Fixes

*   missing CXXFLAGS and LDFLAGS ([a8ccef45](https://github.com/linuxdeepin/deepin-screenshot/commit/a8ccef45c87cdf08e5789fa852f25ce6a8455ca9))



<a name="4.1.5"></a>
### 4.1.5 (2018-12-21)


#### Bug Fixes

*   touch to resize selection not very handy ([9644486d](https://github.com/linuxdeepin/deepin-screenshot/commit/9644486defd0e45fd070cf4b69ef3c636e468e10))



<a name="4.1.4"></a>
### 4.1.4 (2018-11-27)


#### Bug Fixes

*   missing icon file ([710cd417](https://github.com/linuxdeepin/deepin-screenshot/commit/710cd4175a6455c182b251a34ddb976f582600b9))



<a name="4.1.3"></a>
### 4.1.3 (2018-11-23)


#### Features

*   add genericName ([6f67f319](https://github.com/linuxdeepin/deepin-screenshot/commit/6f67f319c9188e145233c3fe6c4030e577c97b5a))



<a name="4.1.2"></a>
## 4.1.2 (2018-10-25)


#### Features

*   use deepin-turbo ([a6d6528f](a6d6528f))
*   add manual id ([15cd1c85](15cd1c85))
*   add dbus service ([d1bdd2a4](d1bdd2a4))
* **hidpi:**  basic hidpi support ([575a326e](575a326e))

#### Bug Fixes

*   qm file install location is incorrect. ([d50c45f0](d50c45f0))
*   not save img for cmdline ([e284f743](e284f743))
*   not save screenshot from cmdline path ([85b51d63](85b51d63))
*   magnifier update not timely ([f0846718](f0846718))
*   manual can't open on flatpak envs ([47111401](47111401))
*   restore blur and mosaic ([8cc26005](8cc26005))
*   save the correct pixmap. ([fab1a62a](fab1a62a))
*   flatpak error readding config file. ([320648ec](320648ec))
*   not draw faker background ([0f7f3f71](0f7f3f71))
*   draw background error ([0cd42039](0cd42039))
*   top level window shortcut misplaced ([83e8b94c](83e8b94c))
*   Adapt lintian ([51eef7f5](51eef7f5))
*   correct a typo in screenshot.cpp ([14f4b936](14f4b936))
*   check controlcenter and hotzone dbus is valid ([32625d1a](32625d1a))
* **flatpak:**  cannot open help manual in flatpak ([7abae000](7abae000))
* **hidpi:**  window background misplaced ([a3e50aa5](a3e50aa5))



<a name="4.1.0"></a>
## 4.1.1 (2018-08-31)


#### Features

*   use deepin-turbo ([a6d6528f](a6d6528f))

<a name="4.0.16"></a>
## 4.0.16 (2018-06-12)

#### Bug Fixes

*   not save img for cmdline ([e284f743](e284f743))
* **flatpak:**  cannot open help manual in flatpak ([7abae000](7abae000))
*   Update version.


<a name="4.0.15"></a>
### 4.0.15 (2018-06-07)


#### Bug Fixes

*   not save screenshot from cmdline path ([85b51d63](85b51d63))

<a name="4.0.14"></a>
## 4.0.14 (2018-05-31)


#### Bug Fixes

*   magnifier update not timely ([f0846718](f0846718))
*   manual can't open on flatpak envs ([47111401](47111401))



<a name="4.0.13"></a>
## 4.0.13 (2018-05-30)


#### Bug Fixes

*   restore blur and mosaic ([8cc26005](8cc26005))



<a name="4.0.12"></a>
## 4.0.12 (2018-05-30)


#### Bug Fixes

*   flatpak error readding config file. ([320648ec](320648ec))
*   not draw faker background ([0f7f3f71](0f7f3f71))
*   draw background error ([0cd42039](0cd42039))



<a name="4.0.12"></a>
## 4.0.12 (2018-05-29)


#### Bug Fixes

*   flatpak error readding config file. ([320648ec](320648ec))
*   not draw faker background ([0f7f3f71](0f7f3f71))
*   draw background error ([0cd42039](0cd42039))



<a name="4.0.11"></a>
## 4.0.11 (2018-03-07)


#### Bug Fixes

*   top level window shortcut misplaced ([83e8b94c](83e8b94c))
*   Adapt lintian ([51eef7f5](51eef7f5))
*   correct a typo in screenshot.cpp ([14f4b936](14f4b936))
*   check controlcenter and hotzone dbus is valid ([32625d1a](32625d1a))
* **hidpi:**  window background misplaced ([a3e50aa5](a3e50aa5))

#### Features

*   add manual id ([15cd1c85](15cd1c85))
*   add dbus service ([d1bdd2a4](d1bdd2a4))
* **hidpi:**  basic hidpi support ([575a326e](575a326e))

==> deepin-screenshot_5.0.0.orig.tar.gz: deepin-screenshot-5.0.0/CHANGELOG.md <==
<a name="4.2.1"></a>
### 4.2.1 (2019-05-29)


#### Bug Fixes

*   cannot input text ([63121fc0](https://github.com/linuxdeepin/deepin-screenshot/commit/63121fc09f8034be86733bc483bc945e756092cf))



<a name=""></a>
##  4.2.0 (2019-05-24)


#### Bug Fixes

*   SaveToSpecificDir not select last path ([3c1fef47](https://github.com/linuxdeepin/deepin-screenshot/commit/3c1fef47b0f125c01c57ed7f7199476d260c0e3b))
* **blur:**  check geometry failed ([f0a82283](https://github.com/linuxdeepin/deepin-screenshot/commit/f0a8228355c34ef5eeb7b43affc96714bd32b149))



<a name="4.1.11"></a>
### 4.1.11 (2019-05-09)


#### Bug Fixes

*   cannot select window on other screen ([2635aa93](https://github.com/linuxdeepin/deepin-screenshot/commit/2635aa93719b9dc0f50f2ef3fc354bf86237d2d8))
*   indicator pos error ([cce7ca59](https://github.com/linuxdeepin/deepin-screenshot/commit/cce7ca59091aa9ed8fb838c5ff4a49b7301780e1))



<a name="4.1.10"></a>
### 4.1.10 (2019-04-26)


*   support HiDPI ([31d2fd94](https://github.com/linuxdeepin/deepin-screenshot/commit/31d2fd940b9ac4d05e88a5ba8606730be57e84ee))

<a name="4.1.9"></a>
## 4.1.9 (2019-04-22)


#### Bug Fixes

*   check path existence ([d8431cc2](https://github.com/linuxdeepin/deepin-screenshot/commit/d8431cc2a94a9f1d49021f279fe688727802d2c0))



<a name="4.1.8"></a>
### 4.1.8 (2019-02-25)


#### Bug Fixes

*   unable to use the open file under other notifications ([0df34426](https://github.com/linuxdeepin/deepin-screenshot/commit/0df34426563b72aefc7d51c3a858dc3ce4451d84))



<a name="4.1.7"></a>
## 4.1.7 (2019-01-25)


#### Features

*   Hold shift to avoid remember save state ([26a5f60a](https://github.com/linuxdeepin/deepin-screenshot/commit/26a5f60a29f5815cbfde00cf8091979df92b450c))



<a name="4.1.6"></a>
### 4.1.6 (2019-01-14)


#### Bug Fixes

*   missing CXXFLAGS and LDFLAGS ([a8ccef45](https://github.com/linuxdeepin/deepin-screenshot/commit/a8ccef45c87cdf08e5789fa852f25ce6a8455ca9))



<a name="4.1.5"></a>
### 4.1.5 (2018-12-21)


#### Bug Fixes

*   touch to resize selection not very handy ([9644486d](https://github.com/linuxdeepin/deepin-screenshot/commit/9644486defd0e45fd070cf4b69ef3c636e468e10))



<a name="4.1.4"></a>
### 4.1.4 (2018-11-27)


#### Bug Fixes

*   missing icon file ([710cd417](https://github.com/linuxdeepin/deepin-screenshot/commit/710cd4175a6455c182b251a34ddb976f582600b9))



<a name="4.1.3"></a>
### 4.1.3 (2018-11-23)


#### Features

*   add genericName ([6f67f319](https://github.com/linuxdeepin/deepin-screenshot/commit/6f67f319c9188e145233c3fe6c4030e577c97b5a))



<a name="4.1.2"></a>
## 4.1.2 (2018-10-25)


#### Features

*   use deepin-turbo ([a6d6528f](a6d6528f))
*   add manual id ([15cd1c85](15cd1c85))
*   add dbus service ([d1bdd2a4](d1bdd2a4))
* **hidpi:**  basic hidpi support ([575a326e](575a326e))

#### Bug Fixes

*   qm file install location is incorrect. ([d50c45f0](d50c45f0))
*   not save img for cmdline ([e284f743](e284f743))
*   not save screenshot from cmdline path ([85b51d63](85b51d63))
*   magnifier update not timely ([f0846718](f0846718))
*   manual can't open on flatpak envs ([47111401](47111401))
*   restore blur and mosaic ([8cc26005](8cc26005))
*   save the correct pixmap. ([fab1a62a](fab1a62a))
*   flatpak error readding config file. ([320648ec](320648ec))
*   not draw faker background ([0f7f3f71](0f7f3f71))
*   draw background error ([0cd42039](0cd42039))
*   top level window shortcut misplaced ([83e8b94c](83e8b94c))
*   Adapt lintian ([51eef7f5](51eef7f5))
*   correct a typo in screenshot.cpp ([14f4b936](14f4b936))
*   check controlcenter and hotzone dbus is valid ([32625d1a](32625d1a))
* **flatpak:**  cannot open help manual in flatpak ([7abae000](7abae000))
* **hidpi:**  window background misplaced ([a3e50aa5](a3e50aa5))



<a name="4.1.0"></a>
## 4.1.1 (2018-08-31)


#### Features

*   use deepin-turbo ([a6d6528f](a6d6528f))

<a name="4.0.16"></a>
## 4.0.16 (2018-06-12)

#### Bug Fixes

*   not save img for cmdline ([e284f743](e284f743))
* **flatpak:**  cannot open help manual in flatpak ([7abae000](7abae000))
*   Update version.


<a name="4.0.15"></a>
### 4.0.15 (2018-06-07)


#### Bug Fixes

*   not save screenshot from cmdline path ([85b51d63](85b51d63))

<a name="4.0.14"></a>
## 4.0.14 (2018-05-31)


#### Bug Fixes

*   magnifier update not timely ([f0846718](f0846718))
*   manual can't open on flatpak envs ([47111401](47111401))



<a name="4.0.13"></a>
## 4.0.13 (2018-05-30)


#### Bug Fixes

*   restore blur and mosaic ([8cc26005](8cc26005))



<a name="4.0.12"></a>
## 4.0.12 (2018-05-30)


#### Bug Fixes

*   flatpak error readding config file. ([320648ec](320648ec))
*   not draw faker background ([0f7f3f71](0f7f3f71))
*   draw background error ([0cd42039](0cd42039))



<a name="4.0.12"></a>
## 4.0.12 (2018-05-29)


#### Bug Fixes

*   flatpak error readding config file. ([320648ec](320648ec))
*   not draw faker background ([0f7f3f71](0f7f3f71))
*   draw background error ([0cd42039](0cd42039))



<a name="4.0.11"></a>
## 4.0.11 (2018-03-07)


#### Bug Fixes

*   top level window shortcut misplaced ([83e8b94c](83e8b94c))
*   Adapt lintian ([51eef7f5](51eef7f5))
*   correct a typo in screenshot.cpp ([14f4b936](14f4b936))
*   check controlcenter and hotzone dbus is valid ([32625d1a](32625d1a))
* **hidpi:**  window background misplaced ([a3e50aa5](a3e50aa5))

#### Features

*   add manual id ([15cd1c85](15cd1c85))
*   add dbus service ([d1bdd2a4](d1bdd2a4))
* **hidpi:**  basic hidpi support ([575a326e](575a326e))
